@@ -4,13 +4,8 @@ from typing import Dict
 import torch
 from torch.optim.optimizer import Optimizer
 
-from pytorch_optimizer.types import (
-    BETAS,
-    CLOSURE,
-    DEFAULT_PARAMETERS,
-    LOSS,
-    PARAMS,
-)
+from pytorch_optimizer.types import BETAS, BUFFER, CLOSURE, DEFAULTS, LOSS, PARAMETERS
+from pytorch_optimizer.utils import is_valid_parameters
 
 
 class RAdam(Optimizer):
@@ -31,53 +26,45 @@ class RAdam(Optimizer):
 
     def __init__(
         self,
-        params: PARAMS,
+        params: PARAMETERS,
         lr: float = 1e-3,
         betas: BETAS = (0.9, 0.999),
-        eps: float = 1e-8,
         weight_decay: float = 0.0,
         n_sma_threshold: int = 5,
         degenerated_to_sgd: bool = False,
+        eps: float = 1e-8,
     ):
-        """Rectified Adam optimizer
-        :param params: PARAMS. iterable of parameters to optimize
-            or dicts defining parameter groups
+        """
+        :param params: PARAMETERS. iterable of parameters to optimize or dicts defining parameter groups
         :param lr: float. learning rate.
-        :param betas: BETAS. coefficients used for computing running averages
-            of gradient and the squared hessian trace
-        :param eps: float. term added to the denominator
-            to improve numerical stability
+        :param betas: BETAS. coefficients used for computing running averages of gradient and the squared hessian trace
         :param weight_decay: float. weight decay (L2 penalty)
         :param n_sma_threshold: int. (recommended is 5)
         :param degenerated_to_sgd: float.
+        :param eps: float. term added to the denominator to improve numerical stability
         """
         self.lr = lr
         self.betas = betas
-        self.eps = eps
         self.weight_decay = weight_decay
         self.n_sma_threshold = n_sma_threshold
         self.degenerated_to_sgd = degenerated_to_sgd
+        self.eps = eps
 
         self.check_valid_parameters()
 
-        if (
-            isinstance(params, (list, tuple))
-            and len(params) > 0
-            and isinstance(params[0], dict)
-        ):
-            for param in params:
-                if 'betas' in param and (
-                    param['betas'][0] != betas[0]
-                    or param['betas'][1] != betas[1]
-                ):
-                    param['buffer'] = [[None, None, None] for _ in range(10)]
+        buffer: BUFFER = [[None, None, None] for _ in range(10)]
 
-        defaults: DEFAULT_PARAMETERS = dict(
+        if is_valid_parameters(params):
+            for param in params:
+                if 'betas' in param and (param['betas'][0] != betas[0] or param['betas'][1] != betas[1]):
+                    param['buffer'] = buffer
+
+        defaults: DEFAULTS = dict(
             lr=lr,
             betas=betas,
             eps=eps,
             weight_decay=weight_decay,
-            buffer=[[None, None, None] for _ in range(10)],
+            buffer=buffer,
         )
 
         super().__init__(params, defaults)
@@ -85,14 +72,14 @@ class RAdam(Optimizer):
     def check_valid_parameters(self):
         if self.lr < 0.0:
             raise ValueError(f'Invalid learning rate : {self.lr}')
-        if self.eps < 0.0:
-            raise ValueError(f'Invalid eps : {self.eps}')
         if self.weight_decay < 0.0:
             raise ValueError(f'Invalid weight_decay : {self.weight_decay}')
         if not 0.0 <= self.betas[0] < 1.0:
             raise ValueError(f'Invalid beta_0 : {self.betas[0]}')
         if not 0.0 <= self.betas[1] < 1.0:
             raise ValueError(f'Invalid beta_1 : {self.betas[1]}')
+        if self.eps < 0.0:
+            raise ValueError(f'Invalid eps : {self.eps}')
 
     def __setstate__(self, state: Dict):
         super().__setstate__(state)
@@ -109,9 +96,7 @@ class RAdam(Optimizer):
 
                 grad = p.grad.data.float()
                 if grad.is_sparse:
-                    raise RuntimeError(
-                        'RAdam does not support sparse gradients'
-                    )
+                    raise RuntimeError('RAdam does not support sparse gradients')
 
                 p_data_fp32 = p.data.float()
 
@@ -123,9 +108,7 @@ class RAdam(Optimizer):
                     state['exp_avg_sq'] = torch.zeros_like(p_data_fp32)
                 else:
                     state['exp_avg'] = state['exp_avg'].type_as(p_data_fp32)
-                    state['exp_avg_sq'] = state['exp_avg_sq'].type_as(
-                        p_data_fp32
-                    )
+                    state['exp_avg_sq'] = state['exp_avg_sq'].type_as(p_data_fp32)
 
                 exp_avg, exp_avg_sq = state['exp_avg'], state['exp_avg_sq']
                 beta1, beta2 = group['betas']
@@ -141,9 +124,7 @@ class RAdam(Optimizer):
                     buffered[0] = state['step']
                     beta2_t = beta2 ** state['step']
                     n_sma_max = 2.0 / (1.0 - beta2) - 1.0
-                    n_sma = n_sma_max - 2.0 * state['step'] * beta2_t / (
-                        1.0 - beta2_t
-                    )
+                    n_sma = n_sma_max - 2.0 * state['step'] * beta2_t / (1.0 - beta2_t)
                     buffered[1] = n_sma
 
                     if n_sma >= self.n_sma_threshold:
@@ -164,19 +145,13 @@ class RAdam(Optimizer):
 
                 if n_sma >= self.n_sma_threshold:
                     if group['weight_decay'] != 0:
-                        p_data_fp32.add_(
-                            -group['weight_decay'] * group['lr'], p_data_fp32
-                        )
+                        p_data_fp32.add_(-group['weight_decay'] * group['lr'], p_data_fp32)
                     denom = exp_avg_sq.sqrt().add_(group['eps'])
-                    p_data_fp32.addcdiv_(
-                        -step_size * group['lr'], exp_avg, denom
-                    )
+                    p_data_fp32.addcdiv_(-step_size * group['lr'], exp_avg, denom)
                     p.data.copy_(p_data_fp32)
                 elif step_size > 0:
                     if group['weight_decay'] != 0:
-                        p_data_fp32.add_(
-                            -group['weight_decay'] * group['lr'], p_data_fp32
-                        )
+                        p_data_fp32.add_(-group['weight_decay'] * group['lr'], p_data_fp32)
                     p_data_fp32.add_(-step_size * group['lr'], exp_avg)
                     p.data.copy_(p_data_fp32)
 
